MethodDescriptor (py4j-java 0.10.9.7 API)

Package py4j.reflection

## Class MethodDescriptor

- java.lang.Object
- - py4j.reflection.MethodDescriptor

-     public class MethodDescriptor
      extends java.lang.Object

  A MethodDescriptor wraps the signature of a method (name, container, parameters).

- - ### Constructor Summary

    Constructors
    Constructor | Description
    --- | ---
    `MethodDescriptor​(java.lang.String name, java.lang.Class container, java.lang.Class[] parameters)` |

  - ### Method Summary

    All Methods Instance Methods Concrete Methods
    Modifier and Type | Method | Description
    --- | --- | ---
    `boolean` | `equals​(java.lang.Object obj)` |
    `java.lang.Class` | `getContainer()` |
    `java.lang.String` | `getInternalRepresentation()` |
    `java.lang.String` | `getName()` |
    `java.util.List<java.lang.Class>` | `getParameters()` |
    `int` | `hashCode()` |
    `java.lang.String` | `toString()` |

    - ### Methods inherited from class java.lang.Object

      `clone, finalize, getClass, notify, notifyAll, wait, wait, wait`

- - ### Constructor Detail

    - #### MethodDescriptor

          public MethodDescriptor​(java.lang.String name,
                                  java.lang.Class container,
                                  java.lang.Class[] parameters)

  - ### Method Detail

    - #### equals

          public boolean equals​(java.lang.Object obj)

      Overrides:
        `equals` in class `java.lang.Object`

    - #### getContainer

          public java.lang.Class getContainer()

    - #### getInternalRepresentation

          public java.lang.String getInternalRepresentation()

    - #### getName

          public java.lang.String getName()

    - #### getParameters

          public java.util.List<java.lang.Class> getParameters()

    - #### hashCode

          public int hashCode()

      Overrides:
        `hashCode` in class `java.lang.Object`

    - #### toString

          public java.lang.String toString()

      Overrides:
        `toString` in class `java.lang.Object`